boofun.utils.exceptions.ErrorCode
=================================

.. currentmodule:: boofun.utils.exceptions

.. autoclass:: ErrorCode


   .. automethod:: __init__






   .. rubric:: Attributes

   .. autosummary::

      ~ErrorCode.VALIDATION_ERROR
      ~ErrorCode.INVALID_INPUT
      ~ErrorCode.INVALID_PARAMETER_VALUE
      ~ErrorCode.INVALID_PARAMETER_TYPE
      ~ErrorCode.PARAMETER_OUT_OF_RANGE
      ~ErrorCode.EMPTY_INPUT
      ~ErrorCode.INVALID_REPRESENTATION
      ~ErrorCode.UNKNOWN_REPRESENTATION
      ~ErrorCode.REPRESENTATION_NOT_AVAILABLE
      ~ErrorCode.INVALID_TRUTH_TABLE
      ~ErrorCode.TRUTH_TABLE_WRONG_SIZE
      ~ErrorCode.TRUTH_TABLE_EMPTY
      ~ErrorCode.TRUTH_TABLE_INVALID_VALUES
      ~ErrorCode.EVALUATION_ERROR
      ~ErrorCode.EVALUATION_FAILED
      ~ErrorCode.CALLABLE_RAISED
      ~ErrorCode.INDEX_OUT_OF_BOUNDS
      ~ErrorCode.CORRUPTED_DATA
      ~ErrorCode.CONVERSION_ERROR
      ~ErrorCode.NO_CONVERSION_PATH
      ~ErrorCode.CONVERSION_FAILED
      ~ErrorCode.INCOMPATIBLE_REPRESENTATIONS
      ~ErrorCode.NO_REPRESENTATIONS
      ~ErrorCode.CONFIGURATION_ERROR
      ~ErrorCode.INVALID_ERROR_MODEL
      ~ErrorCode.INCOMPATIBLE_SPACE
      ~ErrorCode.INVALID_OPTIMIZATION
      ~ErrorCode.RESOURCE_UNAVAILABLE
      ~ErrorCode.NUMBA_UNAVAILABLE
      ~ErrorCode.CUPY_UNAVAILABLE
      ~ErrorCode.MATPLOTLIB_UNAVAILABLE
      ~ErrorCode.SCIPY_UNAVAILABLE
      ~ErrorCode.SYMPY_UNAVAILABLE
      ~ErrorCode.INTERNAL_ERROR
      ~ErrorCode.INVARIANT_VIOLATION
      ~ErrorCode.STATE_CORRUPTION
      ~ErrorCode.ALGORITHM_ERROR
